@@ -17,13 +17,13 @@
 #' @param y  can be either of the following: y values (response rates), a 2-column matrix with positive/negative response counts by dose, a \code{\link{DRtrace}} object or a \code{\link{doseResponse}} object. 
 #' @param x dose levels (if not included in y). 
 #' @param wt weights (if not included in y).
-#' @param target A vector of target response rate(s), for which the percentile dose estimate is needed.
-#' @param full logical, is a more complete output desired (relevant only for doseFind)? if \code{FALSE} (default), only a point estimate of the dose (x) for the provided target rate is returned
+#' @param target A vector of target response rate(s), for which the percentile dose estimate is needed. See Note.
+#' @param full logical, is a more complete output desired (relevant only for doseFind)? if \code{FALSE} (default), only a point estimate of the dose (x) for the provided target rate is returned.
 #' @param extrapolate logical: should extrapolation beyond the range of estimated y values be allowed? Default \code{FALSE}.
 #' @param dec (relevant only for doseFind) logical, is the true function is assumed to be monotone decreasing? Default \code{FALSE}.
 #' @param estfun the name of the dose-response estimation function. Default \code{\link{cirPAVA}}.
 #' @param errOnFlat logical: in case the forward estimate is completely flat making dose-finding infeasible, should an error be returned? Under default (\code{FALSE}), \code{NA}s are returned for the target estimate. 
-#' @param adaptiveShrink logical, should the y-values be pre-shrunk towards an experiment's target? Recommended if data were obtained via an adaptive dose-finding design. See \code{\link{DRshrink}}.
+#' @param adaptiveShrink logical, should the y-values be pre-shrunk towards an experiment's target? Recommended if data were obtained via an adaptive dose-finding design. See \code{\link{DRshrink}} and the Note.
 #' @param starget The shrinkage target. Defaults to \code{target[1]}.
 #' @param ...	Other arguments passed on to \code{\link{doseResponse}} and \code{estfun}.
 
@@ -34,8 +34,13 @@
 #' \item {cir  }  {  a \code{doseResponse} object which is the \code{alg} output of the forward-estimation function}
 #' }
 
+#' @note If the data were obtained from an adaptive dose-finding design and you seek to estimate a dose other than the experiment's target, note that away from the target the estimates are likely biased (Flournoy and Oron, 2019). Use \code{adaptiveShrink=TRUE} to mitigate the bias. In addition, either provide the true target as \code{starget}, or a vector of values to \code{target}, with the first value being the true target.
+
 #' @seealso \code{\link{oldPAVA}},\code{\link{cirPAVA}}. If you'd like point and interval estimates together, use \code{\link{quickInverse}}.
 
+#' @references Flournoy N and Oron AP, 2020. Bias Induced by Adaptive Dose-Finding Designs. Journal of Applied Statistics 47, 2431-2442.
+
+
 #' @export
 
 doseFind<-function(y,x=NULL,wt=NULL,estfun=cirPAVA,target=NULL,full=FALSE,dec=FALSE,extrapolate=FALSE,errOnFlat=FALSE,adaptiveShrink=FALSE,starget=target[1],...) {
@@ -44,7 +49,7 @@ doseFind<-function(y,x=NULL,wt=NULL,estfun=cirPAVA,target=NULL,full=FALSE,dec=FA
 ### converting to doseResponse object 
 ### Basically it's a numeric data frame with x,y,weight, and x increasing
 if(is.null(target)) stop("Must provide target to dose-find for.\n")
-dr=doseResponse(y=y,x=x,wt=wt,...)
+if(!is.doseResponse(y)) dr=doseResponse(y=y,x=x,wt=wt,...) else dr=y
 if (any(is.na(dr))) stop ("Missing values are not allowed.\n")
 # Adaptive-design shrinkage fix
 if(adaptiveShrink) dr=DRshrink(y=dr,target=starget,...)
@@ -65,7 +70,7 @@ if(min(newy)==max(newy))
 }
 
 ### The estimate is generated by using 'approx' with x and y interchanged
-
+#return(pavout)
 tout=approx(x=newy,y=newx,xout=target,ties="ordered",rule=1)$y
 # targets outside y range are provisionally NA'ed... now if so desired, extrapolate
 if(any(is.na(tout)) && extrapolate)
@@ -98,18 +103,20 @@ return (list(targest=tout,input=dr,fwd=pavout$shrinkage,fwdDesign=pavout$output)
 #' @param y  can be either of the following: y values (response rates), a 2-column matrix with positive/negative response counts by dose, a \code{\link{DRtrace}} object or a \code{\link{doseResponse}} object. 
 #' @param x dose levels (if not included in y). 
 #' @param wt weights (if not included in y).
-#' @param target A vector of target response rate(s), for which the percentile dose estimate is needed.
+#' @param target A vector of target response rate(s), for which the percentile dose estimate is needed. See Note.
 #' @param estfun the function to be used for point estimation. Default \code{\link{cirPAVA}}.
 #' @param intfun the function to be used for interval estimation. Default \code{\link{morrisCI}} (see help on that function for additional options).
 #' @param delta logical: should intervals be calculated using the delta ("local") method (default, \code{TRUE}) or back-drawn directly from the forward bounds? See Details.
 #' @param conf numeric, the interval's confidence level as a fraction in (0,1). Default 0.9.
 #' @param resolution numeric: how fine should the grid for the inverse-interval approximation be? Default 100, which seems to be quite enough. See 'Details'.
 #' @param extrapolate logical: should extrapolation beyond the range of estimated y values be allowed? Default \code{FALSE}. Note this affects only the point estimate; interval boundaries are not extrapolated.
-#' @param adaptiveShrink logical, should the y-values be pre-shrunk towards an experiment's target? Recommended when the data were obtained via an adaptive dose-finding design. See \code{\link{DRshrink}}.
+#' @param adaptiveShrink logical, should the y-values be pre-shrunk towards an experiment's target? Recommended when the data were obtained via an adaptive dose-finding design. See \code{\link{DRshrink}} and the Note below.
 #' @param starget The shrinkage target. Defaults to \code{target[1]}.
-#' @param parabola logical: should the interpolation between design points follow a parabola (\code{TRUE}) or a straight line (\code{FALSE}? The latter is default, because CIs tend to be conservative enough already.
+#' @param parabola logical: should the confidence-interval's interpolation between points with observations follow a parabola (\code{TRUE}) creating broader intervals between observations, or a straight line (\code{FALSE}, default)?
 #' @param ...	Other arguments passed on to \code{\link{doseFind}} and \code{\link{quickIsotone}}, and onwards from there.
 
+#' @note If the data were obtained from an adaptive dose-finding design and you seek to estimate a dose other than the experiment's target, note that away from the target the estimates are likely biased (Flournoy and Oron, 2019). Use \code{adaptiveShrink=TRUE} to mitigate the bias. In addition, either provide the true target as \code{starget}, or a vector of values to \code{target}, with the first value being the true target.
+
 #' @return A data frame with 4 elements:
 #' \itemize{
 #' \item {\code{target}  }  { The user-provided target values of y, at which x is estimated}
@@ -117,6 +124,9 @@ return (list(targest=tout,input=dr,fwd=pavout$shrinkage,fwdDesign=pavout$output)
 #' \item {\code{lowerPPconf,upperPPconf}  }  { the interval-boundary estimates for a 'PP'=\code{100*conf} confidence interval}
 #' }
 
+#' @references Flournoy N and Oron AP, 2020. Bias Induced by Adaptive Dose-Finding Designs. Journal of Applied Statistics 47, 2431-2442.
+
+
 #' @seealso \code{\link{quickIsotone}},\code{\link{doseFind}},\code{\link{deltaInverse}}
 #' @example inst/examples/invExamples.r
 #' @export
@@ -127,10 +137,11 @@ quickInverse<-function(y,x=NULL,wt=NULL,target,estfun=cirPAVA, intfun = morrisCI
 
 #### Point estimate first
 dr=doseResponse(y,x,wt)
-# Adaptive-design shrinkage fix
+# Adaptive-design shrinkage fix. We must do it here b/c used for both point and interval
 if(adaptiveShrink) dr=DRshrink(y=dr,target=starget,...)
 m=length(dr$x)
-pestimate=doseFind(y=dr,estfun=estfun,target=target,full=TRUE,extrapolate=extrapolate,adaptiveShrink=adaptiveShrink,...)
+## adaptiveShrink set to FALSE to avoid double-shrinking
+pestimate=doseFind(y=dr,estfun=estfun,target=target,full=TRUE,extrapolate=extrapolate,adaptiveShrink=FALSE,...)
 dout=data.frame(target=target,point=pestimate$targest,low=-Inf,high=Inf)
 if(all(is.na(pestimate$targest)))
 foundPts=pestimate$targest[!is.na(pestimate$targest)]
@@ -138,9 +149,10 @@ foundPts=pestimate$targest[!is.na(pestimate$targest)]
 dout=data.frame(target=target,point=pestimate$targest,low=-Inf,high=Inf)
 
 if(delta) { ## new default, delta-method ("local") intervals
-	dout[,3:4]=deltaInverse(y=dr,target=target,estfun=estfun,intfun=intfun,conf=conf,parabola=parabola,...)
+	dout[,3:4]=deltaInverse(y=dr,target=target,estfun=estfun,intfun=intfun,conf=conf,parabola=parabola,adaptiveShrink=FALSE,...)
 } else {
 #### CI, using "global" interpolation; generally too conservative
+#	if(adaptiveShrink) dr=DRshrink(y=dr,target=starget,...)
 
 	## Calculate forward CIs at high-rez grid
 	higrid=seq(dr$x[1],dr$x[m],length.out=1+resolution*(m-1))
